Cleaning up Javadocs.

Change-Id: I41d075e3e6f6a26b340ce21a5baa8b238dc069ad
diff --git a/core/store/dist/src/main/java/org/onlab/onos/store/flow/package-info.java b/core/store/dist/src/main/java/org/onlab/onos/store/flow/package-info.java
new file mode 100644
index 0000000..2bf1407
--- /dev/null
+++ b/core/store/dist/src/main/java/org/onlab/onos/store/flow/package-info.java
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2014 Open Networking Laboratory
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+/**
+ * Definitions of events and messages pertaining to replication of flow entries.
+ */
+package org.onlab.onos.store.flow;
diff --git a/core/store/dist/src/main/java/org/onlab/onos/store/intent/impl/package-info.java b/core/store/dist/src/main/java/org/onlab/onos/store/intent/impl/package-info.java
new file mode 100644
index 0000000..a58e86f
--- /dev/null
+++ b/core/store/dist/src/main/java/org/onlab/onos/store/intent/impl/package-info.java
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2014 Open Networking Laboratory
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+/**
+ * Implementation of distributed intent store.
+ */
+package org.onlab.onos.store.intent.impl;
diff --git a/core/store/dist/src/main/java/org/onlab/onos/store/serializers/impl/package-info.java b/core/store/dist/src/main/java/org/onlab/onos/store/serializers/impl/package-info.java
new file mode 100644
index 0000000..fcec959
--- /dev/null
+++ b/core/store/dist/src/main/java/org/onlab/onos/store/serializers/impl/package-info.java
@@ -0,0 +1,20 @@
+/*
+ * Copyright 2014 Open Networking Laboratory
+ *
+ * Licensed under the Apache License, Version 2.0 (the "License");
+ * you may not use this file except in compliance with the License.
+ * You may obtain a copy of the License at
+ *
+ *     http://www.apache.org/licenses/LICENSE-2.0
+ *
+ * Unless required by applicable law or agreed to in writing, software
+ * distributed under the License is distributed on an "AS IS" BASIS,
+ * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
+ * See the License for the specific language governing permissions and
+ * limitations under the License.
+ */
+
+/**
+ * Cluster messaging and distributed store serializers.
+ */
+package org.onlab.onos.store.serializers.impl;
diff --git a/docs/pom.xml b/docs/pom.xml
index 655cc31..b49f157 100644
--- a/docs/pom.xml
+++ b/docs/pom.xml
@@ -61,7 +61,13 @@
                         <group>
                             <title>Core Subsystems</title>
                             <packages>
-                                org.onlab.onos.impl:org.onlab.onos.cluster.impl:org.onlab.onos.net.device.impl:org.onlab.onos.net.link.impl:org.onlab.onos.net.host.impl:org.onlab.onos.net.topology.impl:org.onlab.onos.net.packet.impl:org.onlab.onos.net.flow.impl:org.onlab.onos.store.trivial.*:org.onlab.onos.net.*.impl:org.onlab.onos.event.impl:org.onlab.onos.store.*:org.onlab.onos.net.intent.impl:org.onlab.onos.net.proxyarp.impl:org.onlab.onos.mastership.impl:org.onlab.onos.json:org.onlab.onos.json.*:org.onlab.onos.provider.host.impl:org.onlab.onos.provider.lldp.impl:org.onlab.onos.net.statistic.impl
+                                org.onlab.onos.impl:org.onlab.onos.core.impl:org.onlab.onos.cluster.impl:org.onlab.onos.net.device.impl:org.onlab.onos.net.link.impl:org.onlab.onos.net.host.impl:org.onlab.onos.net.topology.impl:org.onlab.onos.net.packet.impl:org.onlab.onos.net.flow.impl:org.onlab.onos.net.*.impl:org.onlab.onos.event.impl:org.onlab.onos.net.intent.impl:org.onlab.onos.net.proxyarp.impl:org.onlab.onos.mastership.impl:org.onlab.onos.net.resource.impl:org.onlab.onos.json:org.onlab.onos.json.*:org.onlab.onos.provider.host.impl:org.onlab.onos.provider.lldp.impl:org.onlab.onos.net.statistic.impl
+                            </packages>
+                        </group>
+                        <group>
+                            <title>Distributed Stores</title>
+                            <packages>
+                                org.onlab.onos.store.*
                             </packages>
                         </group>
                         <group>
@@ -92,12 +98,11 @@
                         <group>
                             <title>Test Instrumentation</title>
                             <packages>
-                                org.onlab.onos.metrics.*:org.onlab.onos.oecfg
+                                org.onlab.onos.metrics.*
                             </packages>
                         </group>
                     </groups>
-                    <excludePackageNames>org.onlab.thirdparty
-                    </excludePackageNames>
+                    <excludePackageNames>org.onlab.thirdparty:org.onlab.onos.oecfg</excludePackageNames>
                 </configuration>
             </plugin>
         </plugins>
diff --git a/utils/misc/src/main/java/org/onlab/api/ItemNotFoundException.java b/utils/misc/src/main/java/org/onlab/util/ItemNotFoundException.java
similarity index 97%
rename from utils/misc/src/main/java/org/onlab/api/ItemNotFoundException.java
rename to utils/misc/src/main/java/org/onlab/util/ItemNotFoundException.java
index fe484d4..01440ab 100644
--- a/utils/misc/src/main/java/org/onlab/api/ItemNotFoundException.java
+++ b/utils/misc/src/main/java/org/onlab/util/ItemNotFoundException.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.api;
+package org.onlab.util;
 
 /**
  * Represents condition where an item is not found or not available.
diff --git a/web/api/src/main/java/org/onlab/onos/rest/exceptions/EntityNotFoundMapper.java b/web/api/src/main/java/org/onlab/onos/rest/exceptions/EntityNotFoundMapper.java
index 4c86fe6..192a2e0 100644
--- a/web/api/src/main/java/org/onlab/onos/rest/exceptions/EntityNotFoundMapper.java
+++ b/web/api/src/main/java/org/onlab/onos/rest/exceptions/EntityNotFoundMapper.java
@@ -15,7 +15,7 @@
  */
 package org.onlab.onos.rest.exceptions;
 
-import org.onlab.api.ItemNotFoundException;
+import org.onlab.util.ItemNotFoundException;
 
 import javax.ws.rs.core.Response;
 
diff --git a/web/pom.xml b/web/pom.xml
index aad2134..b7f3c87 100644
--- a/web/pom.xml
+++ b/web/pom.xml
@@ -132,7 +132,7 @@
                             com.fasterxml.jackson.databind.node,
                             com.google.common.base.*,
                             org.eclipse.jetty.websocket.*,
-                            org.onlab.api.*,
+                            org.onlab.util.*,
                             org.onlab.osgi.*,
                             org.onlab.packet.*,
                             org.onlab.rest.*,
diff --git a/web/api/src/main/java/org/onlab/onos/rest/AbstractWebResource.java b/web/api/src/main/java/org/onlab/onos/rest/AbstractWebResource.java
index ee9adb0..b36bb1b 100644
--- a/web/api/src/main/java/org/onlab/onos/rest/AbstractWebResource.java
+++ b/web/api/src/main/java/org/onlab/onos/rest/AbstractWebResource.java
@@ -17,7 +17,7 @@
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.fasterxml.jackson.databind.node.ObjectNode;
-import org.onlab.api.ItemNotFoundException;
+import org.onlab.util.ItemNotFoundException;
 import org.onlab.onos.codec.CodecContext;
 import org.onlab.onos.codec.CodecService;
 import org.onlab.onos.codec.JsonCodec;
@@ -69,7 +69,7 @@
      * @param message not found message
      * @param <T>     item type
      * @return item if not null
      * @throws org.onlab.api.ItemNotFoundException if item is null
      */
     protected <T> T nullIsNotFound(T item, String message) {
         if (item == null) {
@@ -69,7 +69,7 @@
      * @param <T>     item type
      * @return item if not null
-     * @throws org.onlab.api.ItemNotFoundException if item is null
+     * @throws org.onlab.util.ItemNotFoundException if item is null
      */
     protected <T> T nullIsNotFound(T item, String message) {